.. _std-library-ref:

|Enaml| Standard Widget Library
===============================================================================

The following components are available from the standard library:

.. _std-lib-fields: 

Fields
-------------------------------------------------------------------------------

The following Fields all inherit from Field, and do the appropriate type
of validation:

.. autoenaml_decl:: enaml.stdlib.fields.IntField
.. autoenaml_decl:: enaml.stdlib.fields.FloatField
.. autoenaml_decl:: enaml.stdlib.fields.RegexField

